==> jc-1.4.0.tar.gz: soot/ScenePack.h <==
// public class soot.ScenePack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack

// header file dependencies
// @dep_header soot_Pack

#include "soot/Pack.h"

#ifndef _JC_soot_ScenePack_H_
#define _JC_soot_ScenePack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_ScenePack$sub_refs	_jc_soot_ScenePack$sub_refs;
typedef struct _jc_soot_ScenePack$sub_nonrefs	_jc_soot_ScenePack$sub_nonrefs;
typedef struct _jc_soot_ScenePack$refs	_jc_soot_ScenePack$refs;
typedef struct _jc_soot_ScenePack$nonrefs	_jc_soot_ScenePack$nonrefs;
typedef struct _jc_soot_ScenePack$object	_jc_soot_ScenePack$object;

typedef const struct _jc_soot_ScenePack$vmethods	_jc_soot_ScenePack$vmethods;
typedef const struct _jc_soot_ScenePack$vtable	_jc_soot_ScenePack$vtable;
typedef const struct _jc_soot_ScenePack$vtype	_jc_soot_ScenePack$vtype;

// Constructors
extern void _jc_soot_ScenePack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_ScenePack$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_ScenePack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_ScenePack$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_ScenePack$vmethods {
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_ScenePack$object *);
};

// Vtable
struct _jc_soot_ScenePack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
};

// Vtype
struct _jc_soot_ScenePack$vtype {
	_jc_type			type;
	_jc_soot_ScenePack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_ScenePack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_ScenePack$refs {
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_ScenePack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_ScenePack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
};

// Object instance structure
struct _jc_soot_ScenePack$object {
	_jc_soot_ScenePack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_ScenePack$vtype	*vtype;
	_jc_soot_ScenePack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_ScenePack$vtype _jc_soot_ScenePack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_ScenePack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_ScenePack$class_object;

#endif	/* _JC_soot_ScenePack_H_ */

==> jc-1.4.6.tar.gz: soot/ScenePack.h <==
// public class soot.ScenePack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack

// header file dependencies
// @dep_header soot_Pack

#include "soot/Pack.h"

#ifndef _JC_soot_ScenePack_H_
#define _JC_soot_ScenePack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_ScenePack$sub_refs	_jc_soot_ScenePack$sub_refs;
typedef struct _jc_soot_ScenePack$sub_nonrefs	_jc_soot_ScenePack$sub_nonrefs;
typedef struct _jc_soot_ScenePack$refs	_jc_soot_ScenePack$refs;
typedef struct _jc_soot_ScenePack$nonrefs	_jc_soot_ScenePack$nonrefs;
typedef struct _jc_soot_ScenePack$object	_jc_soot_ScenePack$object;

typedef const struct _jc_soot_ScenePack$vmethods	_jc_soot_ScenePack$vmethods;
typedef const struct _jc_soot_ScenePack$vtable	_jc_soot_ScenePack$vtable;
typedef const struct _jc_soot_ScenePack$vtype	_jc_soot_ScenePack$vtype;

// Constructors
extern void _jc_soot_ScenePack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_ScenePack$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_ScenePack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_ScenePack$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_ScenePack$vmethods {
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_ScenePack$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_ScenePack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
};

// Vtype
struct _jc_soot_ScenePack$vtype {
	_jc_type			type;
	_jc_soot_ScenePack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_ScenePack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_ScenePack$refs {
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_ScenePack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_ScenePack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
};

// Object instance structure
struct _jc_soot_ScenePack$object {
	_jc_soot_ScenePack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_ScenePack$vtype	*vtype;
	_jc_soot_ScenePack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_ScenePack$vtype _jc_soot_ScenePack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_ScenePack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_ScenePack$class_object;

#endif	/* _JC_soot_ScenePack_H_ */
